@@ -81,7 +81,6 @@ sub definitions {
 
 	$project->{save_file_version_number}
 	$project->{timebase}
-	$project->{cache_map}
 	$project->{undo_buffer}
 	$project->{track_version_comments}
 	$project->{track_comments}
@@ -203,7 +202,7 @@ sub definitions {
 		fade_out_level 					=> {ea => 0, 	eadb => -40},
 		unity_level 					=> {ea => 100, 	eadb => 0}, 
 		fade_resolution 				=> 20, # steps per second
-		no_fade_mute_delay				=> 0.03,
+		engine_muting_time				=> 0.03,
 		enforce_channel_bounds			=> 1,
 
 
